==> blesta-5.10.2.zip: blesta/language/it_it/admin_company_general.php <==
<?php
/**
 * Admin Company General
 *
 * @package blesta
 * @subpackage blesta.language.it_it
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGeneral.humanverification.field_submit'] = 'Aggiornamento delle impostazioni';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_forgot'] = 'Il cliente ha dimenticato il suo nome utente';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_reset'] = 'Cliente Reimposta la mia password';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login_reset'] = 'Admin Reimposta la mia password';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login'] = 'Accesso al cliente';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login'] = 'Accesso amministratore';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_shared_key'] = 'Chiave condivisa reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_pub_key'] = 'Chiave del sito reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_internalcaptcha'] = 'Captcha interno';
$lang['AdminCompanyGeneral.humanverification.field_captcha_recaptcha'] = 'reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_none'] = 'Nessuno';
$lang['AdminCompanyGeneral.humanverification.field_captcha'] = 'Captcha';
$lang['AdminCompanyGeneral.humanverification.heading_enabled_forms'] = 'Moduli abilitati';
$lang['AdminCompanyGeneral.humanverification.heading_captcha_provider'] = 'Fornitore di Captcha';
$lang['AdminCompanyGeneral.humanverification.boxtitle_humanverification'] = 'Verifica umana';
$lang['AdminCompanyGeneral.smartsearch.field_submit'] = 'Aggiornamento delle impostazioni';
$lang['AdminCompanyGeneral.smartsearch.field_package_search'] = 'Ricerca per pacchetto';
$lang['AdminCompanyGeneral.smartsearch.field_service_search'] = 'Ricerca di servizio';
$lang['AdminCompanyGeneral.smartsearch.field_transaction_search'] = 'Ricerca per transazione';
$lang['AdminCompanyGeneral.smartsearch.field_quotation_search'] = 'Ricerca di quotazioni';
$lang['AdminCompanyGeneral.smartsearch.field_invoice_search'] = 'Ricerca fatture';
$lang['AdminCompanyGeneral.smartsearch.field_client_search'] = 'Ricerca clienti';
$lang['AdminCompanyGeneral.smartsearch.boxtitle_smartsearch'] = 'Ricerca intelligente';
$lang['AdminCompanyGeneral.marketing.field_submit'] = 'Aggiornamento delle impostazioni';
$lang['AdminCompanyGeneral.marketing.field_show_receive_email_marketing'] = 'Presentare ai clienti l\'opzione di opt-in/opt-out del marketing via e-mail';
$lang['AdminCompanyGeneral.marketing.boxtitle_marketing'] = 'Marketing';
$lang['AdminCompanyGeneral.editcontacttype.field_contacttypesubmit'] = 'Modifica del tipo di contatto';
$lang['AdminCompanyGeneral.editcontacttype.field_is_lang'] = 'Definizione della lingua d\'uso';
$lang['AdminCompanyGeneral.editcontacttype.field_name'] = 'Nome';
$lang['AdminCompanyGeneral.editcontacttype.boxtitle_editcontacttype'] = 'Modifica del tipo di contatto';
$lang['AdminCompanyGeneral.editcontacttype.page_title'] = 'Impostazioni > Azienda > Generale > Modifica tipo di contatto';
$lang['AdminCompanyGeneral.addcontacttype.field_contacttypesubmit'] = 'Creare un tipo di contatto';
$lang['AdminCompanyGeneral.addcontacttype.field_is_lang'] = 'Definizione della lingua d\'uso';
$lang['AdminCompanyGeneral.addcontacttype.field_name'] = 'Nome';
$lang['AdminCompanyGeneral.addcontacttype.boxtitle_addcontacttype'] = 'Creare un tipo di contatto';
$lang['AdminCompanyGeneral.addcontacttype.page_title'] = 'Impostazioni > Azienda > Generale > Crea tipo di contatto';
$lang['AdminCompanyGeneral.!contacttypes.is_lang'] = 'Selezionare questa casella solo se è stata aggiunta una definizione di lingua per questo tipo di contatto nel file della lingua personalizzata.';
$lang['AdminCompanyGeneral.contacttypes.no_results'] = 'Non ci sono tipi di contatto.';
$lang['AdminCompanyGeneral.contacttypes.modal_delete'] = 'L\'eliminazione di questo tipo di contatto farà sì che tutti i contatti assegnati a questo tipo vengano inseriti nel tipo predefinito "Fatturazione". Siete sicuri di voler eliminare questo tipo di contatto?';
$lang['AdminCompanyGeneral.contacttypes.option_delete'] = 'Cancellare';
$lang['AdminCompanyGeneral.contacttypes.option_edit'] = 'Modifica';
$lang['AdminCompanyGeneral.contacttypes.text_no'] = 'No';
$lang['AdminCompanyGeneral.contacttypes.text_yes'] = 'Sì';
$lang['AdminCompanyGeneral.contacttypes.heading_options'] = 'Opzioni';
$lang['AdminCompanyGeneral.contacttypes.heading_define'] = 'Usi Linguistici Definizione';
$lang['AdminCompanyGeneral.contacttypes.heading_name'] = 'Nome';
$lang['AdminCompanyGeneral.contacttypes.boxtitle_types'] = 'Tipi di contatto';
$lang['AdminCompanyGeneral.contacttypes.categorylink_addtype'] = 'Creare un tipo di contatto';
$lang['AdminCompanyGeneral.contacttypes.page_title'] = 'Impostazioni > Azienda > Generale > Tipi di contatto';
$lang['AdminCompanyGeneral.encryption.field_encryptionsubmit'] = 'Aggiornare la passphrase';
$lang['AdminCompanyGeneral.encryption.field_agree'] = 'Ho salvato questa passphrase in un luogo sicuro';
$lang['AdminCompanyGeneral.encryption.field_confirm_new_passphrase'] = 'Conferma la passphrase della chiave privata';
$lang['AdminCompanyGeneral.encryption.field_private_key_passphrase'] = 'Nuova passphrase per la chiave privata';
$lang['AdminCompanyGeneral.encryption.field_current_passphrase'] = 'Passphrase della chiave privata corrente';
$lang['AdminCompanyGeneral.encryption.boxtitle_encryption'] = 'Crittografia';
$lang['AdminCompanyGeneral.!notice.passphrase_set'] = 'ATTENZIONE: è stata impostata una passphrase. È necessario effettuare manualmente i pagamenti in batch con la passphrase. La modifica della passphrase con una passphrase vuota eliminerà questo requisito.';
$lang['AdminCompanyGeneral.!notice.passphrase'] = 'ATTENZIONE: l\'impostazione di una passphrase impedisce l\'elaborazione automatica dei conti di pagamento memorizzati localmente. Sarà necessario eseguire manualmente il batch dei pagamenti inserendo la passphrase. Per ulteriori informazioni su questa funzione, consultare il manuale.';
$lang['AdminCompanyGeneral.encryption.page_title'] = 'Impostazioni > Azienda > Generale > Crittografia';
$lang['AdminCompanyGeneral.international.confirm_uninstall'] = 'Siete sicuri di voler disinstallare la lingua %1$s? Questa lingua verrà disinstallata e tutti i modelli di e-mail in questa lingua verranno eliminati definitivamente.';
$lang['AdminCompanyGeneral.international.confirm_install'] = 'Si è sicuri di voler installare la lingua %1$s?';
$lang['AdminCompanyGeneral.international.option_uninstall'] = 'Disinstallare';
$lang['AdminCompanyGeneral.international.option_install'] = 'Installare';
$lang['AdminCompanyGeneral.international.text_options'] = 'Opzioni';
$lang['AdminCompanyGeneral.international.text_iso'] = 'ISO 639-1, 3166-1';
$lang['AdminCompanyGeneral.international.text_language'] = 'Lingua';
$lang['AdminCompanyGeneral.international.boxtitle_international'] = 'Internazionalizzazione';
$lang['AdminCompanyGeneral.international.page_title'] = 'Impostazioni > Azienda > Generale > Internazionalizzazione';
$lang['AdminCompanyGeneral.!notice.international_languages'] = 'Esiste un progetto di traduzione in crowdsourcing su translate.blesta.com. È possibile contribuire e scaricare le traduzioni delle lingue in questo sito. Per installarlo, decomprimere il contenuto del file nella directory di installazione di Blesta. Quindi, aggiornare questa pagina e fare clic sul link Installa.';
$lang['AdminCompanyGeneral.localization.field.localizationsubmit'] = 'Aggiornamento delle impostazioni';
$lang['AdminCompanyGeneral.localization.field.country'] = 'Paese predefinito';
$lang['AdminCompanyGeneral.localization.field.datetimeformat'] = 'Formato data-ora';
$lang['AdminCompanyGeneral.localization.field.dateformat'] = 'Formato della data';
$lang['AdminCompanyGeneral.localization.field.timezone'] = 'Fuso orario';
$lang['AdminCompanyGeneral.localization.field.monday'] = 'Lunedì';
$lang['AdminCompanyGeneral.localization.field.sunday'] = 'Domenica';
$lang['AdminCompanyGeneral.localization.field.calendar'] = 'Giorno di inizio calendario';
$lang['AdminCompanyGeneral.localization.field.setlanguage'] = 'Il cliente può impostare la lingua';
$lang['AdminCompanyGeneral.localization.field.language'] = 'Lingua predefinita';
$lang['AdminCompanyGeneral.localization.tz_format'] = '(UTC %1$s) %2$s';
$lang['AdminCompanyGeneral.localization.boxtitle_localization'] = 'Localizzazione';
$lang['AdminCompanyGeneral.localization.page_title'] = 'Impostazioni > Azienda > Generale > Localizzazione';
$lang['AdminCompanyGeneral.!tooltip.captcha'] = 'Questo è il captcha utilizzato per impostazione predefinita; il captcha interno richiede l\'estensione GD.';
$lang['AdminCompanyGeneral.!tooltip.country'] = 'Questo è il Paese selezionato di default nei moduli pertinenti.';
$lang['AdminCompanyGeneral.!tooltip.datetime_format'] = 'Imposta il formato della data e dell\'ora. Questo formato viene utilizzato quando si visualizzano la data e l\'ora. Per le opzioni disponibili, consultare il manuale di php.';
$lang['AdminCompanyGeneral.!tooltip.date_format'] = 'Imposta il formato della data. Questo formato viene utilizzato quando si visualizza una data. Per le opzioni disponibili, consultare il manuale di php.';
$lang['AdminCompanyGeneral.!tooltip.timezone'] = 'È il fuso orario del sistema in cui verranno formattate le conversioni di data e ora.';
$lang['AdminCompanyGeneral.!tooltip.calendar_begins'] = 'Impostare il giorno di inizio settimanale del calendario.';
$lang['AdminCompanyGeneral.!tooltip.client_set_lang'] = 'Se questa opzione è selezionata, i clienti possono scegliere la lingua da utilizzare tra quelle disponibili nel sistema.';
$lang['AdminCompanyGeneral.!tooltip.language'] = 'La lingua predefinita utilizzata dal sistema. Per aggiungere altre lingue, vedere Impostazioni di internazionalizzazione.';
$lang['AdminCompanyGeneral.!success.humanverification_updated'] = 'Le impostazioni della verifica umana sono state aggiornate con successo.';
$lang['AdminCompanyGeneral.!success.smartsearch_updated'] = 'Le impostazioni di Smart Search sono state aggiornate con successo.';
$lang['AdminCompanyGeneral.!success.marketing_updated'] = 'Le impostazioni di marketing sono state aggiornate con successo.';
$lang['AdminCompanyGeneral.!success.language_uninstalled'] = 'La lingua %1$s è stata disinstallata con successo.';
$lang['AdminCompanyGeneral.!success.language_installed'] = 'La lingua %1$s è stata installata con successo.';
$lang['AdminCompanyGeneral.!success.contact_type_deleted'] = 'Il tipo di contatto "%1$s" è stato eliminato con successo.';
$lang['AdminCompanyGeneral.!success.contact_type_updated'] = 'Il tipo di contatto "%1$s" è stato aggiornato con successo.';
$lang['AdminCompanyGeneral.!success.contact_type_added'] = 'Il tipo di contatto "%1$s" è stato aggiunto con successo.';
$lang['AdminCompanyGeneral.!success.encryption_updated'] = 'Le impostazioni di crittografia sono state aggiornate con successo.';
$lang['AdminCompanyGeneral.!success.localization_updated'] = 'Le impostazioni di localizzazione sono state aggiornate con successo.';
$lang['AdminCompanyGeneral.!error.captcha_gd'] = 'L\'estensione GD è necessaria per generare il captcha interno.';

==> blesta-5.11.4.zip: blesta/language/it_it/admin_company_general.php <==
<?php
/**
 * Admin Company General
 *
 * @package blesta
 * @subpackage blesta.language.it_it
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGeneral.humanverification.field_submit'] = 'Aggiornamento delle impostazioni';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_forgot'] = 'Il cliente ha dimenticato il suo nome utente';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_reset'] = 'Cliente Reimposta la mia password';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login_reset'] = 'Admin Reimposta la mia password';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login'] = 'Accesso al cliente';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login'] = 'Accesso amministratore';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_shared_key'] = 'Chiave condivisa reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_pub_key'] = 'Chiave del sito reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_internalcaptcha'] = 'Captcha interno';
$lang['AdminCompanyGeneral.humanverification.field_captcha_recaptcha'] = 'reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_none'] = 'Nessuno';
$lang['AdminCompanyGeneral.humanverification.field_captcha'] = 'Captcha';
$lang['AdminCompanyGeneral.humanverification.heading_enabled_forms'] = 'Moduli abilitati';
$lang['AdminCompanyGeneral.humanverification.heading_captcha_provider'] = 'Fornitore di Captcha';
$lang['AdminCompanyGeneral.humanverification.boxtitle_humanverification'] = 'Verifica umana';
$lang['AdminCompanyGeneral.smartsearch.field_submit'] = 'Aggiornamento delle impostazioni';
$lang['AdminCompanyGeneral.smartsearch.field_package_search'] = 'Ricerca per pacchetto';
$lang['AdminCompanyGeneral.smartsearch.field_service_search'] = 'Ricerca di servizio';
$lang['AdminCompanyGeneral.smartsearch.field_transaction_search'] = 'Ricerca per transazione';
$lang['AdminCompanyGeneral.smartsearch.field_quotation_search'] = 'Ricerca di quotazioni';
$lang['AdminCompanyGeneral.smartsearch.field_invoice_search'] = 'Ricerca fatture';
$lang['AdminCompanyGeneral.smartsearch.field_client_search'] = 'Ricerca clienti';
$lang['AdminCompanyGeneral.smartsearch.boxtitle_smartsearch'] = 'Ricerca intelligente';
$lang['AdminCompanyGeneral.marketing.field_submit'] = 'Aggiornamento delle impostazioni';
$lang['AdminCompanyGeneral.marketing.field_show_receive_email_marketing'] = 'Presentare ai clienti l\'opzione di opt-in/opt-out del marketing via e-mail';
$lang['AdminCompanyGeneral.marketing.boxtitle_marketing'] = 'Marketing';
$lang['AdminCompanyGeneral.editcontacttype.field_contacttypesubmit'] = 'Modifica del tipo di contatto';
$lang['AdminCompanyGeneral.editcontacttype.field_is_lang'] = 'Definizione della lingua d\'uso';
$lang['AdminCompanyGeneral.editcontacttype.field_name'] = 'Nome';
$lang['AdminCompanyGeneral.editcontacttype.boxtitle_editcontacttype'] = 'Modifica del tipo di contatto';
$lang['AdminCompanyGeneral.editcontacttype.page_title'] = 'Impostazioni > Azienda > Generale > Modifica tipo di contatto';
$lang['AdminCompanyGeneral.addcontacttype.field_contacttypesubmit'] = 'Creare un tipo di contatto';
$lang['AdminCompanyGeneral.addcontacttype.field_is_lang'] = 'Definizione della lingua d\'uso';
$lang['AdminCompanyGeneral.addcontacttype.field_name'] = 'Nome';
$lang['AdminCompanyGeneral.addcontacttype.boxtitle_addcontacttype'] = 'Creare un tipo di contatto';
$lang['AdminCompanyGeneral.addcontacttype.page_title'] = 'Impostazioni > Azienda > Generale > Crea tipo di contatto';
$lang['AdminCompanyGeneral.!contacttypes.is_lang'] = 'Selezionare questa casella solo se è stata aggiunta una definizione di lingua per questo tipo di contatto nel file della lingua personalizzata.';
$lang['AdminCompanyGeneral.contacttypes.no_results'] = 'Non ci sono tipi di contatto.';
$lang['AdminCompanyGeneral.contacttypes.modal_delete'] = 'L\'eliminazione di questo tipo di contatto farà sì che tutti i contatti assegnati a questo tipo vengano inseriti nel tipo predefinito "Fatturazione". Siete sicuri di voler eliminare questo tipo di contatto?';
$lang['AdminCompanyGeneral.contacttypes.option_delete'] = 'Cancellare';
$lang['AdminCompanyGeneral.contacttypes.option_edit'] = 'Modifica';
$lang['AdminCompanyGeneral.contacttypes.text_no'] = 'No';
$lang['AdminCompanyGeneral.contacttypes.text_yes'] = 'Sì';
$lang['AdminCompanyGeneral.contacttypes.heading_options'] = 'Opzioni';
$lang['AdminCompanyGeneral.contacttypes.heading_define'] = 'Usi Linguistici Definizione';
$lang['AdminCompanyGeneral.contacttypes.heading_name'] = 'Nome';
$lang['AdminCompanyGeneral.contacttypes.boxtitle_types'] = 'Tipi di contatto';
$lang['AdminCompanyGeneral.contacttypes.categorylink_addtype'] = 'Creare un tipo di contatto';
$lang['AdminCompanyGeneral.contacttypes.page_title'] = 'Impostazioni > Azienda > Generale > Tipi di contatto';
$lang['AdminCompanyGeneral.encryption.field_encryptionsubmit'] = 'Aggiornare la passphrase';
$lang['AdminCompanyGeneral.encryption.field_agree'] = 'Ho salvato questa passphrase in un luogo sicuro';
$lang['AdminCompanyGeneral.encryption.field_confirm_new_passphrase'] = 'Conferma la passphrase della chiave privata';
$lang['AdminCompanyGeneral.encryption.field_private_key_passphrase'] = 'Nuova passphrase per la chiave privata';
$lang['AdminCompanyGeneral.encryption.field_current_passphrase'] = 'Passphrase della chiave privata corrente';
$lang['AdminCompanyGeneral.encryption.boxtitle_encryption'] = 'Crittografia';
$lang['AdminCompanyGeneral.!notice.passphrase_set'] = 'ATTENZIONE: è stata impostata una passphrase. È necessario effettuare manualmente i pagamenti in batch con la passphrase. La modifica della passphrase con una passphrase vuota eliminerà questo requisito.';
$lang['AdminCompanyGeneral.!notice.passphrase'] = 'ATTENZIONE: l\'impostazione di una passphrase impedisce l\'elaborazione automatica dei conti di pagamento memorizzati localmente. Sarà necessario eseguire manualmente il batch dei pagamenti inserendo la passphrase. Per ulteriori informazioni su questa funzione, consultare il manuale.';
$lang['AdminCompanyGeneral.encryption.page_title'] = 'Impostazioni > Azienda > Generale > Crittografia';
$lang['AdminCompanyGeneral.international.confirm_uninstall'] = 'Siete sicuri di voler disinstallare la lingua %1$s? Questa lingua verrà disinstallata e tutti i modelli di e-mail in questa lingua verranno eliminati definitivamente.';
$lang['AdminCompanyGeneral.international.confirm_install'] = 'Si è sicuri di voler installare la lingua %1$s?';
$lang['AdminCompanyGeneral.international.option_uninstall'] = 'Disinstallare';
$lang['AdminCompanyGeneral.international.option_install'] = 'Installare';
$lang['AdminCompanyGeneral.international.text_options'] = 'Opzioni';
$lang['AdminCompanyGeneral.international.text_iso'] = 'ISO 639-1, 3166-1';
$lang['AdminCompanyGeneral.international.text_language'] = 'Lingua';
$lang['AdminCompanyGeneral.international.boxtitle_international'] = 'Internazionalizzazione';
$lang['AdminCompanyGeneral.international.page_title'] = 'Impostazioni > Azienda > Generale > Internazionalizzazione';
$lang['AdminCompanyGeneral.!notice.international_languages'] = 'Esiste un progetto di traduzione in crowdsourcing su translate.blesta.com. È possibile contribuire e scaricare le traduzioni delle lingue in questo sito. Per installarlo, decomprimere il contenuto del file nella directory di installazione di Blesta. Quindi, aggiornare questa pagina e fare clic sul link Installa.';
$lang['AdminCompanyGeneral.localization.field.localizationsubmit'] = 'Aggiornamento delle impostazioni';
$lang['AdminCompanyGeneral.localization.field.country'] = 'Paese predefinito';
$lang['AdminCompanyGeneral.localization.field.datetimeformat'] = 'Formato data-ora';
$lang['AdminCompanyGeneral.localization.field.dateformat'] = 'Formato della data';
$lang['AdminCompanyGeneral.localization.field.timezone'] = 'Fuso orario';
$lang['AdminCompanyGeneral.localization.field.monday'] = 'Lunedì';
$lang['AdminCompanyGeneral.localization.field.sunday'] = 'Domenica';
$lang['AdminCompanyGeneral.localization.field.calendar'] = 'Giorno di inizio calendario';
$lang['AdminCompanyGeneral.localization.field.setlanguage'] = 'Il cliente può impostare la lingua';
$lang['AdminCompanyGeneral.localization.field.language'] = 'Lingua predefinita';
$lang['AdminCompanyGeneral.localization.tz_format'] = '(UTC %1$s) %2$s';
$lang['AdminCompanyGeneral.localization.boxtitle_localization'] = 'Localizzazione';
$lang['AdminCompanyGeneral.localization.page_title'] = 'Impostazioni > Azienda > Generale > Localizzazione';
$lang['AdminCompanyGeneral.!tooltip.captcha'] = 'Questo è il captcha utilizzato per impostazione predefinita; il captcha interno richiede l\'estensione GD.';
$lang['AdminCompanyGeneral.!tooltip.country'] = 'Questo è il Paese selezionato di default nei moduli pertinenti.';
$lang['AdminCompanyGeneral.!tooltip.datetime_format'] = 'Imposta il formato della data e dell\'ora. Questo formato viene utilizzato quando si visualizzano la data e l\'ora. Per le opzioni disponibili, consultare il manuale di php.';
$lang['AdminCompanyGeneral.!tooltip.date_format'] = 'Imposta il formato della data. Questo formato viene utilizzato quando si visualizza una data. Per le opzioni disponibili, consultare il manuale di php.';
$lang['AdminCompanyGeneral.!tooltip.timezone'] = 'È il fuso orario del sistema in cui verranno formattate le conversioni di data e ora.';
$lang['AdminCompanyGeneral.!tooltip.calendar_begins'] = 'Impostare il giorno di inizio settimanale del calendario.';
$lang['AdminCompanyGeneral.!tooltip.client_set_lang'] = 'Se questa opzione è selezionata, i clienti possono scegliere la lingua da utilizzare tra quelle disponibili nel sistema.';
$lang['AdminCompanyGeneral.!tooltip.language'] = 'La lingua predefinita utilizzata dal sistema. Per aggiungere altre lingue, vedere Impostazioni di internazionalizzazione.';
$lang['AdminCompanyGeneral.!success.humanverification_updated'] = 'Le impostazioni della verifica umana sono state aggiornate con successo.';
$lang['AdminCompanyGeneral.!success.smartsearch_updated'] = 'Le impostazioni di Smart Search sono state aggiornate con successo.';
$lang['AdminCompanyGeneral.!success.marketing_updated'] = 'Le impostazioni di marketing sono state aggiornate con successo.';
$lang['AdminCompanyGeneral.!success.language_uninstalled'] = 'La lingua %1$s è stata disinstallata con successo.';
$lang['AdminCompanyGeneral.!success.language_installed'] = 'La lingua %1$s è stata installata con successo. Ricordarsi di aggiornare le e-mail, i pacchetti e i gruppi di pacchetti con il contenuto della nuova lingua.';
$lang['AdminCompanyGeneral.!success.contact_type_deleted'] = 'Il tipo di contatto "%1$s" è stato eliminato con successo.';
$lang['AdminCompanyGeneral.!success.contact_type_updated'] = 'Il tipo di contatto "%1$s" è stato aggiornato con successo.';
$lang['AdminCompanyGeneral.!success.contact_type_added'] = 'Il tipo di contatto "%1$s" è stato aggiunto con successo.';
$lang['AdminCompanyGeneral.!success.encryption_updated'] = 'Le impostazioni di crittografia sono state aggiornate con successo.';
$lang['AdminCompanyGeneral.!success.localization_updated'] = 'Le impostazioni di localizzazione sono state aggiornate con successo.';
$lang['AdminCompanyGeneral.!error.captcha_gd'] = 'L\'estensione GD è necessaria per generare il captcha interno.';
